# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/cost_analysis/v1/cost_query_set.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/cost_analysis/v1/cost_query_set.proto\x12\x1dspaceone.api.cost_analysis.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\x8d\x01\n\x19\x43reateCostQuerySetRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xa8\x01\n\x19UpdateCostQuerySetRequest\x12\x19\n\x11\x63ost_query_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"C\n\x13\x43ostQuerySetRequest\x12\x19\n\x11\x63ost_query_set_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"T\n\x16GetCostQuerySetRequest\x12\x19\n\x11\x63ost_query_set_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8c\x01\n\x11\x43ostQuerySetQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x19\n\x11\x63ost_query_set_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0f\n\x07user_id\x18\x04 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xd8\x01\n\x10\x43ostQuerySetInfo\x12\x19\n\x11\x63ost_query_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\x12\x12\n\ncreated_at\x18\x15 \x01(\t\x12\x12\n\nupdated_at\x18\x16 \x01(\t\"j\n\x11\x43ostQuerySetsInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.cost_analysis.v1.CostQuerySetInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"`\n\x15\x43ostQuerySetStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xf2\x07\n\x0c\x43ostQuerySet\x12\x9e\x01\n\x06\x63reate\x12\x38.spaceone.api.cost_analysis.v1.CreateCostQuerySetRequest\x1a/.spaceone.api.cost_analysis.v1.CostQuerySetInfo\")\x82\xd3\xe4\x93\x02#\"!/cost-analysis/v1/cost-query-sets\x12\xb1\x01\n\x06update\x12\x38.spaceone.api.cost_analysis.v1.UpdateCostQuerySetRequest\x1a/.spaceone.api.cost_analysis.v1.CostQuerySetInfo\"<\x82\xd3\xe4\x93\x02\x36\x1a\x34/cost-analysis/v1/cost-query-set/{cost_query_set_id}\x12\x92\x01\n\x06\x64\x65lete\x12\x32.spaceone.api.cost_analysis.v1.CostQuerySetRequest\x1a\x16.google.protobuf.Empty\"<\x82\xd3\xe4\x93\x02\x36*4/cost-analysis/v1/cost-query-set/{cost_query_set_id}\x12\xab\x01\n\x03get\x12\x35.spaceone.api.cost_analysis.v1.GetCostQuerySetRequest\x1a/.spaceone.api.cost_analysis.v1.CostQuerySetInfo\"<\x82\xd3\xe4\x93\x02\x36\x12\x34/cost-analysis/v1/cost-query-set/{cost_query_set_id}\x12\xc1\x01\n\x04list\x12\x30.spaceone.api.cost_analysis.v1.CostQuerySetQuery\x1a\x30.spaceone.api.cost_analysis.v1.CostQuerySetsInfo\"U\x82\xd3\xe4\x93\x02O\x12!/cost-analysis/v1/cost-query-setsZ*\"(/cost-analysis/v1/cost-query-sets/search\x12\x85\x01\n\x04stat\x12\x34.spaceone.api.cost_analysis.v1.CostQuerySetStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/cost-analysis/v1/cost-query-sets/statb\x06proto3')



_CREATECOSTQUERYSETREQUEST = DESCRIPTOR.message_types_by_name['CreateCostQuerySetRequest']
_UPDATECOSTQUERYSETREQUEST = DESCRIPTOR.message_types_by_name['UpdateCostQuerySetRequest']
_COSTQUERYSETREQUEST = DESCRIPTOR.message_types_by_name['CostQuerySetRequest']
_GETCOSTQUERYSETREQUEST = DESCRIPTOR.message_types_by_name['GetCostQuerySetRequest']
_COSTQUERYSETQUERY = DESCRIPTOR.message_types_by_name['CostQuerySetQuery']
_COSTQUERYSETINFO = DESCRIPTOR.message_types_by_name['CostQuerySetInfo']
_COSTQUERYSETSINFO = DESCRIPTOR.message_types_by_name['CostQuerySetsInfo']
_COSTQUERYSETSTATQUERY = DESCRIPTOR.message_types_by_name['CostQuerySetStatQuery']
CreateCostQuerySetRequest = _reflection.GeneratedProtocolMessageType('CreateCostQuerySetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECOSTQUERYSETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CreateCostQuerySetRequest)
  })
_sym_db.RegisterMessage(CreateCostQuerySetRequest)

UpdateCostQuerySetRequest = _reflection.GeneratedProtocolMessageType('UpdateCostQuerySetRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECOSTQUERYSETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.UpdateCostQuerySetRequest)
  })
_sym_db.RegisterMessage(UpdateCostQuerySetRequest)

CostQuerySetRequest = _reflection.GeneratedProtocolMessageType('CostQuerySetRequest', (_message.Message,), {
  'DESCRIPTOR' : _COSTQUERYSETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostQuerySetRequest)
  })
_sym_db.RegisterMessage(CostQuerySetRequest)

GetCostQuerySetRequest = _reflection.GeneratedProtocolMessageType('GetCostQuerySetRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCOSTQUERYSETREQUEST,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.GetCostQuerySetRequest)
  })
_sym_db.RegisterMessage(GetCostQuerySetRequest)

CostQuerySetQuery = _reflection.GeneratedProtocolMessageType('CostQuerySetQuery', (_message.Message,), {
  'DESCRIPTOR' : _COSTQUERYSETQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostQuerySetQuery)
  })
_sym_db.RegisterMessage(CostQuerySetQuery)

CostQuerySetInfo = _reflection.GeneratedProtocolMessageType('CostQuerySetInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTQUERYSETINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostQuerySetInfo)
  })
_sym_db.RegisterMessage(CostQuerySetInfo)

CostQuerySetsInfo = _reflection.GeneratedProtocolMessageType('CostQuerySetsInfo', (_message.Message,), {
  'DESCRIPTOR' : _COSTQUERYSETSINFO,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostQuerySetsInfo)
  })
_sym_db.RegisterMessage(CostQuerySetsInfo)

CostQuerySetStatQuery = _reflection.GeneratedProtocolMessageType('CostQuerySetStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _COSTQUERYSETSTATQUERY,
  '__module__' : 'spaceone.api.cost_analysis.v1.cost_query_set_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.cost_analysis.v1.CostQuerySetStatQuery)
  })
_sym_db.RegisterMessage(CostQuerySetStatQuery)

_COSTQUERYSET = DESCRIPTOR.services_by_name['CostQuerySet']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COSTQUERYSET.methods_by_name['create']._options = None
  _COSTQUERYSET.methods_by_name['create']._serialized_options = b'\202\323\344\223\002#\"!/cost-analysis/v1/cost-query-sets'
  _COSTQUERYSET.methods_by_name['update']._options = None
  _COSTQUERYSET.methods_by_name['update']._serialized_options = b'\202\323\344\223\0026\0324/cost-analysis/v1/cost-query-set/{cost_query_set_id}'
  _COSTQUERYSET.methods_by_name['delete']._options = None
  _COSTQUERYSET.methods_by_name['delete']._serialized_options = b'\202\323\344\223\0026*4/cost-analysis/v1/cost-query-set/{cost_query_set_id}'
  _COSTQUERYSET.methods_by_name['get']._options = None
  _COSTQUERYSET.methods_by_name['get']._serialized_options = b'\202\323\344\223\0026\0224/cost-analysis/v1/cost-query-set/{cost_query_set_id}'
  _COSTQUERYSET.methods_by_name['list']._options = None
  _COSTQUERYSET.methods_by_name['list']._serialized_options = b'\202\323\344\223\002O\022!/cost-analysis/v1/cost-query-setsZ*\"(/cost-analysis/v1/cost-query-sets/search'
  _COSTQUERYSET.methods_by_name['stat']._options = None
  _COSTQUERYSET.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/cost-analysis/v1/cost-query-sets/stat'
  _CREATECOSTQUERYSETREQUEST._serialized_start=209
  _CREATECOSTQUERYSETREQUEST._serialized_end=350
  _UPDATECOSTQUERYSETREQUEST._serialized_start=353
  _UPDATECOSTQUERYSETREQUEST._serialized_end=521
  _COSTQUERYSETREQUEST._serialized_start=523
  _COSTQUERYSETREQUEST._serialized_end=590
  _GETCOSTQUERYSETREQUEST._serialized_start=592
  _GETCOSTQUERYSETREQUEST._serialized_end=676
  _COSTQUERYSETQUERY._serialized_start=679
  _COSTQUERYSETQUERY._serialized_end=819
  _COSTQUERYSETINFO._serialized_start=822
  _COSTQUERYSETINFO._serialized_end=1038
  _COSTQUERYSETSINFO._serialized_start=1040
  _COSTQUERYSETSINFO._serialized_end=1146
  _COSTQUERYSETSTATQUERY._serialized_start=1148
  _COSTQUERYSETSTATQUERY._serialized_end=1244
  _COSTQUERYSET._serialized_start=1247
  _COSTQUERYSET._serialized_end=2257
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.cost_analysis.v1 import cost_query_set_pb2 as spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2


class CostQuerySetStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.create = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.CostQuerySet/create',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CreateCostQuerySetRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.CostQuerySet/update',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.UpdateCostQuerySetRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.FromString,
                )
        self.delete = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.CostQuerySet/delete',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.CostQuerySet/get',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.GetCostQuerySetRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.CostQuerySet/list',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.cost_analysis.v1.CostQuerySet/stat',
                request_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class CostQuerySetServicer(object):
    """Missing associated documentation comment in .proto file."""

    def create(self, request, context):
        """
        desc: Creates a new CostQuerySet. You can make your own custom query that meets your needs, and input it as an `option` parameter of the resource. Queries such as `group_by` and `granularity` are provided by default.
        request_example: >-
        {
        "name": "project_provider_region",
        "options": {
        "primary_group_by": "project_id",
        "filters": {},
        "period": {
        "end": "2022-07-31T23:59:59Z",
        "start": "2022-07-01T00:00:00Z"
        },
        "group_by": [
        "project_id",
        "provider",
        "region_code"
        ],
        "stack": false,
        "granularity": "ACCUMULATED"}
        }
        response_example: >-
        {
        "cost_query_set_id": "query-76a58ea5d02c",
        "name": "project_provider_region",
        "options": {
        "group_by": [
        "project_id",
        "provider",
        "region_code"
        ],
        "filters": {},
        "primary_group_by": "project_id",
        "period": {
        "end": "2022-07-31T23:59:59Z",
        "start": "2022-07-01T00:00:00Z"
        },
        "stack": false,
        "granularity": "ACCUMULATED"
        },
        "tags": {},
        "user_id": "test@cloudforet.io",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T06:11:03.701Z",
        "updated_at": "2022-07-19T06:11:03.701Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific CostQuerySet. You can make changes in the details of queries.
        request_example: >-
        {
        "cost_query_set_id": "query-76a58ea5d02c",
        "options": {
        "stack": false,
        "filters": {},
        "period": {
        "start": "2022-07-01T00:00:00Z",
        "end": "2022-07-31T23:59:59Z"
        },
        "group_by": [
        "project_id",
        "provider",
        "region_code",
        "product"
        ],
        "granularity": "ACCUMULATED",
        "primary_group_by": "project_id"
        }
        }
        response_example: >-
        {
        "cost_query_set_id": "query-76a58ea5d02c",
        "name": "project_provider_region",
        "options": {
        "primary_group_by": "project_id",
        "stack": false,
        "period": {
        "end": "2022-07-31T23:59:59Z",
        "start": "2022-07-01T00:00:00Z"
        },
        "filters": {},
        "granularity": "ACCUMULATED",
        "group_by": [
        "project_id",
        "provider",
        "region_code",
        "product"
        ]
        },
        "tags": {},
        "user_id": "test@cloudforet.io",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-07-19T06:11:03.701Z",
        "updated_at": "2022-07-19T06:11:03.701Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def delete(self, request, context):
        """
        desc: Deletes a specific CostQuerySet. You must specify the `cost_query_set_id` of the CostQuerySet to delete.
        request_example: >-
        {
        "cost_query_set_id": "query-16ae671dc8fb"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific CostQuerySet. Prints detailed information about the CostQuerySet, including the details of queries.
        request_example: >-
        {
        "cost_query_set_id": "query-16ae671dc8fb"
        }
        response_example: >-
        {
        "cost_query_set_id": "query-16ae671dc8fb",
        "name": "3 month product pie chart",
        "options": {
        "group_by": [
        "product"
        ],
        "period": {
        "start": "2022-01-01",
        "end": "2022-03-31"
        },
        "primary_group_by": "product",
        "stack": false,
        "filters": {},
        "granularity": "ACCUMULATED"
        },
        "tags": {},
        "user_id": "test1@cloudforet.io",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-08T03:37:31.404Z",
        "updated_at": "2022-03-08T03:37:31.404Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all CostQuerySets. You can use a query to get a filtered list of CostQuerySets.
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "cost_query_set_id": "query-16ae671dc8fb",
        "name": "3 month product pie chart",
        "options": {
        "primary_group_by": "product",
        "granularity": "ACCUMULATED",
        "stack": false,
        "filters": {},
        "period": {
        "end": "2022-03-31",
        "start": "2022-01-01"
        },
        "group_by": [
        "product"
        ]
        },
        "tags": {},
        "user_id": "yuda@mz.co.kr",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-08T03:37:31.404Z",
        "updated_at": "2022-03-08T03:37:31.404Z"
        },
        {
        "cost_query_set_id": "query-d90addf25e4b",
        "name": "6 month project group",
        "options": {
        "primary_group_by": "project_group_id",
        "period": {
        "start": "2021-10-01",
        "end": "2022-03-31"
        },
        "stack": false,
        "group_by": [
        "project_group_id"
        ],
        "granularity": "MONTHLY",
        "filters": {}
        },
        "tags": {},
        "user_id": "yuda@mz.co.kr",
        "domain_id": "domain-58010aa2e451",
        "created_at": "2022-03-14T09:29:54.306Z",
        "updated_at": "2022-03-14T09:29:54.306Z"
        }
        ],
        "total_count": 34
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_CostQuerySetServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'create': grpc.unary_unary_rpc_method_handler(
                    servicer.create,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CreateCostQuerySetRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.UpdateCostQuerySetRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.SerializeToString,
            ),
            'delete': grpc.unary_unary_rpc_method_handler(
                    servicer.delete,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.GetCostQuerySetRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.cost_analysis.v1.CostQuerySet', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class CostQuerySet(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def create(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.CostQuerySet/create',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CreateCostQuerySetRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.CostQuerySet/update',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.UpdateCostQuerySetRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def delete(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.CostQuerySet/delete',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.CostQuerySet/get',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.GetCostQuerySetRequest.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.CostQuerySet/list',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetQuery.SerializeToString,
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.cost_analysis.v1.CostQuerySet/stat',
            spaceone_dot_api_dot_cost__analysis_dot_v1_dot_cost__query__set__pb2.CostQuerySetStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/monitoring/plugin/event.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*spaceone/api/monitoring/plugin/event.proto\x12\x1espaceone.api.monitoring.plugin\x1a\x1cgoogle/protobuf/struct.proto\"_\n\x0cParseRequest\x12(\n\x07options\x18\x01 \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04\x64\x61ta\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xab\x03\n\tEventInfo\x12\x11\n\tevent_key\x18\x01 \x01(\t\x12\x12\n\nevent_type\x18\x02 \x01(\t\x12\r\n\x05title\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x44\n\x08severity\x18\x05 \x01(\x0e\x32\x32.spaceone.api.monitoring.plugin.EventInfo.Severity\x12)\n\x08resource\x18\x06 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0c\n\x04rule\x18\x07 \x01(\t\x12\x13\n\x0boccurred_at\x18\x08 \x01(\t\x12\x30\n\x0f\x61\x64\x64itional_info\x18\t \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\timage_url\x18\n \x01(\t\x12\x10\n\x08provider\x18\x0b \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\x0c \x01(\t\"W\n\x08Severity\x12\x08\n\x04NONE\x10\x00\x12\x0c\n\x08\x43RITICAL\x10\x01\x12\t\n\x05\x45RROR\x10\x02\x12\x0b\n\x07WARNING\x10\x03\x12\x08\n\x04INFO\x10\x04\x12\x11\n\rNOT_AVAILABLE\x10\x05\"H\n\nEventsInfo\x12:\n\x07results\x18\x01 \x03(\x0b\x32).spaceone.api.monitoring.plugin.EventInfo2l\n\x05\x45vent\x12\x63\n\x05parse\x12,.spaceone.api.monitoring.plugin.ParseRequest\x1a*.spaceone.api.monitoring.plugin.EventsInfo\"\x00\x62\x06proto3')



_PARSEREQUEST = DESCRIPTOR.message_types_by_name['ParseRequest']
_EVENTINFO = DESCRIPTOR.message_types_by_name['EventInfo']
_EVENTSINFO = DESCRIPTOR.message_types_by_name['EventsInfo']
_EVENTINFO_SEVERITY = _EVENTINFO.enum_types_by_name['Severity']
ParseRequest = _reflection.GeneratedProtocolMessageType('ParseRequest', (_message.Message,), {
  'DESCRIPTOR' : _PARSEREQUEST,
  '__module__' : 'spaceone.api.monitoring.plugin.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.ParseRequest)
  })
_sym_db.RegisterMessage(ParseRequest)

EventInfo = _reflection.GeneratedProtocolMessageType('EventInfo', (_message.Message,), {
  'DESCRIPTOR' : _EVENTINFO,
  '__module__' : 'spaceone.api.monitoring.plugin.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.EventInfo)
  })
_sym_db.RegisterMessage(EventInfo)

EventsInfo = _reflection.GeneratedProtocolMessageType('EventsInfo', (_message.Message,), {
  'DESCRIPTOR' : _EVENTSINFO,
  '__module__' : 'spaceone.api.monitoring.plugin.event_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.monitoring.plugin.EventsInfo)
  })
_sym_db.RegisterMessage(EventsInfo)

_EVENT = DESCRIPTOR.services_by_name['Event']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PARSEREQUEST._serialized_start=108
  _PARSEREQUEST._serialized_end=203
  _EVENTINFO._serialized_start=206
  _EVENTINFO._serialized_end=633
  _EVENTINFO_SEVERITY._serialized_start=546
  _EVENTINFO_SEVERITY._serialized_end=633
  _EVENTSINFO._serialized_start=635
  _EVENTSINFO._serialized_end=707
  _EVENT._serialized_start=709
  _EVENT._serialized_end=817
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/statistics/v1/storage.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2
from spaceone.api.statistics.v1 import resource_pb2 as spaceone_dot_api_dot_statistics_dot_v1_dot_resource__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/statistics/v1/storage.proto\x12\x1aspaceone.api.statistics.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\x1a)spaceone/api/statistics/v1/resource.proto\"\x9b\x01\n\rPluginRequest\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0e\n\x06schema\x18\x05 \x01(\t\"\x98\x01\n\nPluginInfo\x12\x11\n\tplugin_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tsecret_id\x18\x04 \x01(\t\x12)\n\x08metadata\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"\xb1\x01\n\x16RegisterStorageRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12>\n\x0bplugin_info\x18\x02 \x01(\x0b\x32).spaceone.api.statistics.v1.PluginRequest\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x0b \x01(\t\x12\x11\n\tdomain_id\x18\x0c \x01(\t\"r\n\x14UpdateStorageRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12%\n\x04tags\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\xac\x01\n\x1aUpdateStoragePluginRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12(\n\x07options\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12,\n\x0bsecret_data\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"7\n\x0eStorageRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"H\n\x11GetStorageRequest\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x8f\x01\n\x0cStorageQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x12\n\nstorage_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\r\n\x05state\x18\x04 \x01(\t\x12\x0f\n\x07user_id\x18\x05 \x01(\t\x12\x11\n\tdomain_id\x18\x06 \x01(\t\"\x8e\x03\n\x0bStorageInfo\x12\x12\n\nstorage_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12<\n\x05state\x18\x03 \x01(\x0e\x32-.spaceone.api.statistics.v1.StorageInfo.State\x12(\n\x07options\x18\x04 \x01(\x0b\x32\x17.google.protobuf.Struct\x12+\n\ncapability\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12;\n\x0bplugin_info\x18\x06 \x01(\x0b\x32&.spaceone.api.statistics.v1.PluginInfo\x12%\n\x04tags\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x0f\n\x07user_id\x18\x08 \x01(\t\x12\x11\n\tdomain_id\x18\t \x01(\t\x12\x12\n\ncreated_at\x18\n \x01(\t\",\n\x05State\x12\x08\n\x04NONE\x10\x00\x12\x0b\n\x07\x45NABLED\x10\x01\x12\x0c\n\x08\x44ISABLED\x10\x02\"]\n\x0cStoragesInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.statistics.v1.StorageInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"[\n\x10StorageStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb8\x0b\n\x07Storage\x12\x88\x01\n\x08register\x12\x32.spaceone.api.statistics.v1.RegisterStorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/statistics/v1/storages\x12\x90\x01\n\x06update\x12\x30.spaceone.api.statistics.v1.UpdateStorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"+\x82\xd3\xe4\x93\x02%\x1a#/statistics/v1/storage/{storage_id}\x12\xa9\x01\n\rupdate_plugin\x12\x36.spaceone.api.statistics.v1.UpdateStoragePluginRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"7\x82\xd3\xe4\x93\x02\x31\x1a//spot-automation/v1/storage/{storage_id}/plugin\x12\x93\x01\n\rverify_plugin\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\x16.google.protobuf.Empty\">\x82\xd3\xe4\x93\x02\x38\"6/spot-automation/v1/storage/{storage_id}/plugin/verify\x12\x92\x01\n\x06\x65nable\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"3\x82\xd3\xe4\x93\x02-\x1a+/statistics/v1/storage/{schedule_id}/enable\x12\x94\x01\n\x07\x64isable\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\"4\x82\xd3\xe4\x93\x02.\x1a,/statistics/v1/storage/{schedule_id}/disable\x12~\n\nderegister\x12*.spaceone.api.statistics.v1.StorageRequest\x1a\x16.google.protobuf.Empty\",\x82\xd3\xe4\x93\x02&*$/statistics/v1/storage/{schedule_id}\x12\x8b\x01\n\x03get\x12-.spaceone.api.statistics.v1.GetStorageRequest\x1a\'.spaceone.api.statistics.v1.StorageInfo\",\x82\xd3\xe4\x93\x02&\x12$/statistics/v1/storage/{schedule_id}\x12\x9d\x01\n\x04list\x12(.spaceone.api.statistics.v1.StorageQuery\x1a(.spaceone.api.statistics.v1.StoragesInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/statistics/v1/storagesZ \"\x1e/statistics/v1/storages/search\x12s\n\x04stat\x12,.spaceone.api.statistics.v1.StorageStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/statistics/v1/storages/statb\x06proto3')



_PLUGINREQUEST = DESCRIPTOR.message_types_by_name['PluginRequest']
_PLUGININFO = DESCRIPTOR.message_types_by_name['PluginInfo']
_REGISTERSTORAGEREQUEST = DESCRIPTOR.message_types_by_name['RegisterStorageRequest']
_UPDATESTORAGEREQUEST = DESCRIPTOR.message_types_by_name['UpdateStorageRequest']
_UPDATESTORAGEPLUGINREQUEST = DESCRIPTOR.message_types_by_name['UpdateStoragePluginRequest']
_STORAGEREQUEST = DESCRIPTOR.message_types_by_name['StorageRequest']
_GETSTORAGEREQUEST = DESCRIPTOR.message_types_by_name['GetStorageRequest']
_STORAGEQUERY = DESCRIPTOR.message_types_by_name['StorageQuery']
_STORAGEINFO = DESCRIPTOR.message_types_by_name['StorageInfo']
_STORAGESINFO = DESCRIPTOR.message_types_by_name['StoragesInfo']
_STORAGESTATQUERY = DESCRIPTOR.message_types_by_name['StorageStatQuery']
_STORAGEINFO_STATE = _STORAGEINFO.enum_types_by_name['State']
PluginRequest = _reflection.GeneratedProtocolMessageType('PluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _PLUGINREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.PluginRequest)
  })
_sym_db.RegisterMessage(PluginRequest)

PluginInfo = _reflection.GeneratedProtocolMessageType('PluginInfo', (_message.Message,), {
  'DESCRIPTOR' : _PLUGININFO,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.PluginInfo)
  })
_sym_db.RegisterMessage(PluginInfo)

RegisterStorageRequest = _reflection.GeneratedProtocolMessageType('RegisterStorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _REGISTERSTORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.RegisterStorageRequest)
  })
_sym_db.RegisterMessage(RegisterStorageRequest)

UpdateStorageRequest = _reflection.GeneratedProtocolMessageType('UpdateStorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.UpdateStorageRequest)
  })
_sym_db.RegisterMessage(UpdateStorageRequest)

UpdateStoragePluginRequest = _reflection.GeneratedProtocolMessageType('UpdateStoragePluginRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATESTORAGEPLUGINREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.UpdateStoragePluginRequest)
  })
_sym_db.RegisterMessage(UpdateStoragePluginRequest)

StorageRequest = _reflection.GeneratedProtocolMessageType('StorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageRequest)
  })
_sym_db.RegisterMessage(StorageRequest)

GetStorageRequest = _reflection.GeneratedProtocolMessageType('GetStorageRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETSTORAGEREQUEST,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.GetStorageRequest)
  })
_sym_db.RegisterMessage(GetStorageRequest)

StorageQuery = _reflection.GeneratedProtocolMessageType('StorageQuery', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEQUERY,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageQuery)
  })
_sym_db.RegisterMessage(StorageQuery)

StorageInfo = _reflection.GeneratedProtocolMessageType('StorageInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGEINFO,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageInfo)
  })
_sym_db.RegisterMessage(StorageInfo)

StoragesInfo = _reflection.GeneratedProtocolMessageType('StoragesInfo', (_message.Message,), {
  'DESCRIPTOR' : _STORAGESINFO,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StoragesInfo)
  })
_sym_db.RegisterMessage(StoragesInfo)

StorageStatQuery = _reflection.GeneratedProtocolMessageType('StorageStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _STORAGESTATQUERY,
  '__module__' : 'spaceone.api.statistics.v1.storage_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.statistics.v1.StorageStatQuery)
  })
_sym_db.RegisterMessage(StorageStatQuery)

_STORAGE = DESCRIPTOR.services_by_name['Storage']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _STORAGE.methods_by_name['register']._options = None
  _STORAGE.methods_by_name['register']._serialized_options = b'\202\323\344\223\002\031\"\027/statistics/v1/storages'
  _STORAGE.methods_by_name['update']._options = None
  _STORAGE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002%\032#/statistics/v1/storage/{storage_id}'
  _STORAGE.methods_by_name['update_plugin']._options = None
  _STORAGE.methods_by_name['update_plugin']._serialized_options = b'\202\323\344\223\0021\032//spot-automation/v1/storage/{storage_id}/plugin'
  _STORAGE.methods_by_name['verify_plugin']._options = None
  _STORAGE.methods_by_name['verify_plugin']._serialized_options = b'\202\323\344\223\0028\"6/spot-automation/v1/storage/{storage_id}/plugin/verify'
  _STORAGE.methods_by_name['enable']._options = None
  _STORAGE.methods_by_name['enable']._serialized_options = b'\202\323\344\223\002-\032+/statistics/v1/storage/{schedule_id}/enable'
  _STORAGE.methods_by_name['disable']._options = None
  _STORAGE.methods_by_name['disable']._serialized_options = b'\202\323\344\223\002.\032,/statistics/v1/storage/{schedule_id}/disable'
  _STORAGE.methods_by_name['deregister']._options = None
  _STORAGE.methods_by_name['deregister']._serialized_options = b'\202\323\344\223\002&*$/statistics/v1/storage/{schedule_id}'
  _STORAGE.methods_by_name['get']._options = None
  _STORAGE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002&\022$/statistics/v1/storage/{schedule_id}'
  _STORAGE.methods_by_name['list']._options = None
  _STORAGE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/statistics/v1/storagesZ \"\036/statistics/v1/storages/search'
  _STORAGE.methods_by_name['stat']._options = None
  _STORAGE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/statistics/v1/storages/stat'
  _PLUGINREQUEST._serialized_start=239
  _PLUGINREQUEST._serialized_end=394
  _PLUGININFO._serialized_start=397
  _PLUGININFO._serialized_end=549
  _REGISTERSTORAGEREQUEST._serialized_start=552
  _REGISTERSTORAGEREQUEST._serialized_end=729
  _UPDATESTORAGEREQUEST._serialized_start=731
  _UPDATESTORAGEREQUEST._serialized_end=845
  _UPDATESTORAGEPLUGINREQUEST._serialized_start=848
  _UPDATESTORAGEPLUGINREQUEST._serialized_end=1020
  _STORAGEREQUEST._serialized_start=1022
  _STORAGEREQUEST._serialized_end=1077
  _GETSTORAGEREQUEST._serialized_start=1079
  _GETSTORAGEREQUEST._serialized_end=1151
  _STORAGEQUERY._serialized_start=1154
  _STORAGEQUERY._serialized_end=1297
  _STORAGEINFO._serialized_start=1300
  _STORAGEINFO._serialized_end=1698
  _STORAGEINFO_STATE._serialized_start=1654
  _STORAGEINFO_STATE._serialized_end=1698
  _STORAGESINFO._serialized_start=1700
  _STORAGESINFO._serialized_end=1793
  _STORAGESTATQUERY._serialized_start=1795
  _STORAGESTATQUERY._serialized_end=1886
  _STORAGE._serialized_start=1889
  _STORAGE._serialized_end=3353
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.plugin.v1 import supervisor_pb2 as spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2


class SupervisorStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.publish = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/publish',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PublishSupervisorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
                )
        self.register = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/register',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RegisterSupervisorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/update',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RegisterSupervisorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
                )
        self.deregister = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/deregister',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/enable',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/disable',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
                )
        self.recover_plugin = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/recover_plugin',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RecoverPluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginInfo.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/get',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.GetSupervisorRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/list',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/stat',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )
        self.list_plugins = channel.unary_unary(
                '/spaceone.api.plugin.v1.Supervisor/list_plugins',
                request_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginsInfo.FromString,
                )


class SupervisorServicer(object):
    """Missing associated documentation comment in .proto file."""

    def publish(self, request, context):
        """
        desc: Creates a new Supervisor. Only Users with the `MANAGED` permission can set the Supervisor `public`. The Supervisor manages the lifecycle of plugin instances by the Supervisor's state. When a Supervisor is created, the state of the resource is `PENDING`. If the state remains the same for 5 minutes, the state is changed to `DISCONNECTED`.
        note: ''
        request_example: >-
        {
        "name": "test",
        "hostname": "dev-test2",
        "secret_key": "xxxxx",
        "tags": {
        "a": "b"
        }
        }
        response_example: >-
        {
        "supervisor_id": "supervisor-525982f2ae9a",
        "name": "test",
        "hostname": "dev-test2",
        "state": "ENABLED",
        "domain_id": "domain-1c5a6b8181ad",
        "tags": {
        "a": "b"
        },
        "labels": {},
        "created_at": "2022-01-15T05:42:02.999Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def register(self, request, context):
        """
        desc: Registers a specific Supervisor. You must specify the `supervisor_id` of the Supervisor to register. The `state` of the Supervisor changes from `PENDING` to `ENABLED`.
        note: ''
        request_example: >-
        {

        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Supervisor. You can make changes in Supervisor settings, including `labels`, `tags`, and the `bool` type parameter `is_public`.
        note: ''
        request_example: >-
        {
        "supervisor_id": "supervisor-525982f2ae9a",
        "is_public": true,
        "priority": 10,
        "labels": {
        "a": "b"
        },
        "tags": {
        "c": "d"
        },
        "domain_id": "domain-1c5a6b8181ad"
        }
        response_example: >-
        {
        "supervisor_id": "supervisor-525982f2ae9a",
        "name": "test",
        "hostname": "dev-test2",
        "state": "ENABLED",
        "is_public": true,
        "domain_id": "domain-1c5a6b8181ad",
        "tags": {
        "a": "b"
        },
        "labels": {
        "c": "d"
        },
        "created_at": "2022-06-15T05:42:02.999Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deregister(self, request, context):
        """
        desc: Deregisters and deletes a specific Supervisor. You must specify the `supervisor_id` of the Supervisor to deregister.
        note: ''
        request_example: >-
        {
        "supervisor_id": "supervisor-d73011256d55"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific Supervisor. By changing the `state` parameter to `ENABLED`, the Supervisor can deploy or delete the `pod` of the plugin instance.
        note: ''
        request_example: >-
        {
        "supervisor_id": "supervisor-d73011256d55"
        }
        response_example: >-
        {
        "supervisor_id": "supervisor-d73011256d55",
        "name": "test-in-plugins",
        "hostname": "dev-test3",
        "state": "ENABLED",
        "domain_id": "domain-1c5a6b8181ad",
        "tags": {
        "a": "b"
        },
        "labels": {},
        "created_at": "2022-06-15T06:27:51.904Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific Supervisor. By changing the `state` parameter to `DISABLED`, the Supervisor cannot deploy or delete the `pod` of the plugin instance.
        note: ''
        request_example: >-
        {
        "supervisor_id": "supervisor-d73011256d55"
        }
        response_example: >-
        {
        "supervisor_id": "supervisor-d73011256d55",
        "name": "test-in-plugins",
        "hostname": "dev-test3",
        "state": "DISABLED",
        "domain_id": "domain-1c5a6b8181ad",
        "tags": {
        "a": "b"
        },
        "labels": {},
        "created_at": "2022-06-15T06:27:51.904Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def recover_plugin(self, request, context):
        """
        desc: Recovers a specific plugin instance in a specific Supervisor. Changes the `state` of the Supervisor to `RE-PROVISIONING`.
        note: ''
        request_example: >-
        {
        "supervisor_id": "supervisor-a4c287cba676",
        "plugin_id": "plugin-api-direct-mon-webhook",
        "version": "1.1.0"
        }
        response_example: >-
        {

        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Supervisors. You can use a query to get a filtered list of Supervisors.
        note: ''
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "supervisor_id": "supervisor-3a091f899539",
        "name": "root",
        "hostname": "dev-supervisor.svc.cluster.local",
        "state": "ENABLED",
        "is_public": true,
        "domain_id": "domain-1c5a6b8181ad",
        "labels": {},
        "created_at": "2020-05-12T00:24:48.250Z"
        },
        {
        "supervisor_id": "supervisor-a4c287cba676",
        "name": "test",
        "hostname": "dev-test",
        "state": "ENABLED",
        "domain_id": "domain-1c5a6b8181ad",
        "tags": {
        "a": "b"
        },
        "labels": {},
        "created_at": "2022-06-15T05:39:15.886Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list_plugins(self, request, context):
        """
        desc: Gets a list of all plugin instances regardless of Supervisors. Prints detailed information about the plugin instances, including `version`, `state`, and the relevant Supervisor.
        note: ''
        request_example: >-
        {
        "query": {}
        }
        response_example: >-
        {
        "results": [
        {
        "plugin_id": "plugin-openstack-inven-collector",
        "version": "0.4.1.20220609.122832",
        "state": "ACTIVE",
        "endpoint": "grpc://plugin-openstack-inven-collector-vbnnsoszfjsneiqz.dev-supervisor.svc.cluster.local:50051",
        "supervisor_id": "supervisor-3a091f899539",
        "supervisor_name": "root",
        "managed": true,
        "endpoints": [
        "grpc://172.16.16.234:50051"
        ]
        },
        {
        "plugin_id": "plugin-zabbix-mon-webhook",
        "version": "1.0",
        "state": "ACTIVE",
        "endpoint": "grpc://plugin-zabbix-mon-webhook-dgqqfqsqidieeuk.dev-supervisor.svc.cluster.local:50051",
        "supervisor_id": "supervisor-3a091f899539",
        "supervisor_name": "root",
        "managed": true,
        "endpoints": [
        "grpc://172.16.16.130:50051"
        ]
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_SupervisorServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'publish': grpc.unary_unary_rpc_method_handler(
                    servicer.publish,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PublishSupervisorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.SerializeToString,
            ),
            'register': grpc.unary_unary_rpc_method_handler(
                    servicer.register,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RegisterSupervisorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RegisterSupervisorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.SerializeToString,
            ),
            'deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.deregister,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.SerializeToString,
            ),
            'recover_plugin': grpc.unary_unary_rpc_method_handler(
                    servicer.recover_plugin,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RecoverPluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginInfo.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.GetSupervisorRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
            'list_plugins': grpc.unary_unary_rpc_method_handler(
                    servicer.list_plugins,
                    request_deserializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginsInfo.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.plugin.v1.Supervisor', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Supervisor(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def publish(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/publish',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PublishSupervisorRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/register',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RegisterSupervisorRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/update',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RegisterSupervisorRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/deregister',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/enable',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/disable',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def recover_plugin(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/recover_plugin',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.RecoverPluginRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/get',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.GetSupervisorRequest.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/list',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorQuery.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/stat',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.SupervisorStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list_plugins(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.plugin.v1.Supervisor/list_plugins',
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginQuery.SerializeToString,
            spaceone_dot_api_dot_plugin_dot_v1_dot_supervisor__pb2.PluginsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from spaceone.api.repository.v1 import plugin_pb2 as spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2


class PluginStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.register = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/register',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.CreatePluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
                )
        self.update = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/update',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.UpdatePluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
                )
        self.deregister = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/deregister',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_empty__pb2.Empty.FromString,
                )
        self.enable = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/enable',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
                )
        self.disable = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/disable',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
                )
        self.get_versions = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/get_versions',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.RepositoryPluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.VersionsInfo.FromString,
                )
        self.get = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/get',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.GetRepositoryPluginRequest.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
                )
        self.list = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/list',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginQuery.SerializeToString,
                response_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginsInfo.FromString,
                )
        self.stat = channel.unary_unary(
                '/spaceone.api.repository.v1.Plugin/stat',
                request_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginStatQuery.SerializeToString,
                response_deserializer=google_dot_protobuf_dot_struct__pb2.Struct.FromString,
                )


class PluginServicer(object):
    """Missing associated documentation comment in .proto file."""

    def register(self, request, context):
        """
        desc: Registers a Plugin. The parameter `registry_type`, meaning container registry type, can be either `DOCKER_HUB` or `AWS_PUBLIC_ECR`. The default value of the `registry_type` is `DOCKER_HUB`. The parameter `registry_url` is required if the `registry_type` is not `DOCKER_HUB`. The parameter `image` is limited to 40 characters.
        request_example: >-
        {
        "name": "JIRA Issue notification",
        "service_type": "notification.Procotol",
        "image": "pyengine/plugin-jira-noti-protocol",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "provider": "atlassian",
        "capability": {
        "supported_schema": [
        "atlassian_jira"
        ]
        },
        "template": {
        "options": {
        "schema": {
        "type": "object",
        "required": [],
        "properties": {
        "project_id": {
        "type": "string",
        "title": "Project ID",
        "minLength": 4.0
        },
        "sa_name": {
        "title": "Service Account",
        "type": "string",
        "minLength": 4.0
        }
        }
        }
        }
        },
        "labels": [
        "jira",
        "atlassian",
        "notification"
        ],
        "tags": {
        "description": "Atlassian JIRA Issue notification",
        "icon": "https://icon-path/jira-icon.png"
        }
        }
        response_example: >-
        {
        "plugin_id": "plugin-jira-noti-protocol",
        "name": "JIRA Issue notification",
        "image": "pyengine/plugin-jira-noti-protocol",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "notification.Procotol",
        "provider": "atlassian",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {
        "supported_schema": [
        "atlassian_jira"
        ]
        },
        "template": {
        "options": {
        "schema": {
        "type": "object",
        "required": [],
        "properties": {
        "project_id": {
        "type": "string",
        "title": "Project ID",
        "minLength": 4.0
        },
        "sa_name": {
        "title": "Service Account",
        "type": "string",
        "minLength": 4.0
        }
        }
        }
        }
        },
        "labels": [
        "jira",
        "atlassian",
        "notification"
        ],
        "tags": {
        "description": "Atlassian JIRA Issue notification",
        "icon": "https://icon-path/jira-icon.png"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:02:38.094Z",
        "updated_at": "2022-01-01T08:02:38.094Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def update(self, request, context):
        """
        desc: Updates a specific Plugin registered. A Plugin can be updated only if its Repository's `repository_type` is `local`. You can make changes in Plugin settings, including `template` and its options, `schema`.
        request_example: >-
        {
        "name": "JIRA Issue notification",
        "capability": {
        "supported_schema": [
        "atlassian_jira"
        ]
        },
        "template": {
        "options": {
        "schema": {
        "type": "object",
        "required": [],
        "properties": {
        "project_id": {
        "type": "string",
        "title": "Project ID",
        "minLength": 4.0
        },
        "sa_name": {
        "title": "Service Account",
        "type": "string",
        "minLength": 4.0
        }
        }
        }
        }
        },
        "labels": [
        "jira",
        "atlassian",
        "notification"
        ],
        "tags": {
        "description": "Atlassian JIRA Issue notification",
        "icon": "https://icon-path/jira-icon.png"
        }
        }
        response_example: >-
        {
        "plugin_id": "plugin-jira-noti-protocol",
        "name": "JIRA Issue notification",
        "image": "pyengine/plugin-jira-noti-protocol",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "notification.Procotol",
        "provider": "atlassian",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {
        "supported_schema": [
        "atlassian_jira"
        ]
        },
        "template": {
        "options": {
        "schema": {
        "type": "object",
        "required": [],
        "properties": {
        "project_id": {
        "type": "string",
        "title": "Project ID",
        "minLength": 4.0
        },
        "sa_name": {
        "title": "Service Account",
        "type": "string",
        "minLength": 4.0
        }
        }
        }
        }
        },
        "labels": [
        "jira",
        "atlassian",
        "notification"
        ],
        "tags": {
        "description": "Atlassian JIRA Issue notification",
        "spaceone:plugin_name": "plugin-jira-noti-protocol",
        "icon": "https://icon-path/jira-icon.png"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-123456789012",
        "created_at": "2022-01-01T08:02:38.094Z",
        "updated_at": "2022-01-01T08:02:38.094Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def deregister(self, request, context):
        """
        desc: Deregisters and deletes a specific Plugin. You must specify the `plugin_id` of the Plugin to deregister.
        request_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "name": "AWS SNS Webhook",
        "image": "pyengine/plugin-aws-sns-mon-webhook",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "monitoring.Webhook",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {},
        "template": {},
        "labels": [],
        "tags": {
        "icon": "https://icon-path/Amazon-SNS.svg"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T08:14:23.175Z",
        "updated_at": "2022-01-01T08:14:23.175Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def enable(self, request, context):
        """
        desc: Enables a specific Plugin. If the Plugin is enabled, the Plugin can be used as its parameter `state` becomes `ENABLED`.
        request_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "name": "AWS SNS Webhook",
        "image": "pyengine/plugin-aws-sns-mon-webhook",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "monitoring.Webhook",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {},
        "template": {},
        "labels": [],
        "tags": {
        "icon": "https://icon-path/Amazon-SNS.svg"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T08:14:23.175Z",
        "updated_at": "2022-01-01T08:14:23.175Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def disable(self, request, context):
        """
        desc: Disables a specific Plugin. If the Plugin is disabled, the Plugin cannot be used as its parameter `state` becomes `DISABLED`.
        request_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "name": "AWS SNS Webhook",
        "image": "pyengine/plugin-aws-sns-mon-webhook",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "monitoring.Webhook",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {},
        "template": {},
        "labels": [],
        "tags": {
        "icon": "https://icon-path/Amazon-SNS.svg"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T08:14:23.175Z",
        "updated_at": "2022-01-01T08:14:23.175Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get_versions(self, request, context):
        """
        desc: Gets all version data of a specific Plugin from its Repository. The parameter `plugin_id` is used as an identifier of a Plugin to get version data.
        request_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "total_count": 1,
        "results": [
        "1.2.2",
        "1.2.1.20220429.104002",
        "1.2.1.20220422.161421",
        "1.2.1.20220411.113807",
        "1.2.1"
        ]
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def get(self, request, context):
        """
        desc: Gets a specific Plugin. Prints detailed information about the Plugin, including  `image`, `registry_url`, and `state`.
        request_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "domain_id": "domain-123456789012"
        }
        response_example: >-
        {
        "plugin_id": "plugin-aws-sns-mon-webhook",
        "name": "AWS SNS Webhook",
        "image": "pyengine/plugin-aws-sns-mon-webhook",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "monitoring.Webhook",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {},
        "template": {},
        "labels": [],
        "tags": {
        "icon": "https://icon-url/Amazon-SNS.svg"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2021-06-14T08:14:23.175Z",
        "updated_at": "2021-06-14T08:14:23.175Z"
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def list(self, request, context):
        """
        desc: Gets a list of all Plugins registered in a specific Repository. The parameter `repository_id` is used as an identifier of a Repository to get its list of Plugins. You can use a query to get a filtered list of Plugins.
        request_example: >-
        {
        "query": {},
        "repository_id": "repo-123456789012"
        }
        response_example: >-
        {
        "results": [
        {
        "plugin_id": "plugin-api-direct-mon-webhook",
        "name": "API Direct Webhook",
        "image": "pyengine/plugin-api-direct-mon-webhook",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "monitoring.Webhook",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {},
        "template": {},
        "labels": [],
        "tags": {
        "icon": "https://icon-url/icon.svg"
        },
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T03:25:10.408Z",
        "updated_at": "2022-01-01T03:25:10.408Z"
        },
        {
        "plugin_id": "plugin-aws-hyperbilling-cost-datasource",
        "name": "AWS HyperBilling Cost Analysis Data Source",
        "image": "pyengine/plugin-aws-hyperbilling-cost-datasource",
        "registry_url": "registry.hub.docker.com",
        "state": "ENABLED",
        "service_type": "cost_analysis.DataSoruce",
        "registry_type": "DOCKER_HUB",
        "registry_config": {},
        "capability": {},
        "template": {},
        "labels": [],
        "tags": {},
        "repository_info": {
        "repository_id": "repo-123456789012",
        "name": "Marketplace",
        "repository_type": "remote"
        },
        "domain_id": "domain-987654321098",
        "created_at": "2022-01-01T04:56:55.082Z",
        "updated_at": "2022-01-01T04:56:55.082Z"
        }
        ],
        "total_count": 2
        }
        """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')

    def stat(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_PluginServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'register': grpc.unary_unary_rpc_method_handler(
                    servicer.register,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.CreatePluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.SerializeToString,
            ),
            'update': grpc.unary_unary_rpc_method_handler(
                    servicer.update,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.UpdatePluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.SerializeToString,
            ),
            'deregister': grpc.unary_unary_rpc_method_handler(
                    servicer.deregister,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.FromString,
                    response_serializer=google_dot_protobuf_dot_empty__pb2.Empty.SerializeToString,
            ),
            'enable': grpc.unary_unary_rpc_method_handler(
                    servicer.enable,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.SerializeToString,
            ),
            'disable': grpc.unary_unary_rpc_method_handler(
                    servicer.disable,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.SerializeToString,
            ),
            'get_versions': grpc.unary_unary_rpc_method_handler(
                    servicer.get_versions,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.RepositoryPluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.VersionsInfo.SerializeToString,
            ),
            'get': grpc.unary_unary_rpc_method_handler(
                    servicer.get,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.GetRepositoryPluginRequest.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.SerializeToString,
            ),
            'list': grpc.unary_unary_rpc_method_handler(
                    servicer.list,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginQuery.FromString,
                    response_serializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginsInfo.SerializeToString,
            ),
            'stat': grpc.unary_unary_rpc_method_handler(
                    servicer.stat,
                    request_deserializer=spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginStatQuery.FromString,
                    response_serializer=google_dot_protobuf_dot_struct__pb2.Struct.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'spaceone.api.repository.v1.Plugin', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class Plugin(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def register(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/register',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.CreatePluginRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def update(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/update',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.UpdatePluginRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def deregister(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/deregister',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.SerializeToString,
            google_dot_protobuf_dot_empty__pb2.Empty.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def enable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/enable',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def disable(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/disable',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get_versions(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/get_versions',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.RepositoryPluginRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.VersionsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def get(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/get',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.GetRepositoryPluginRequest.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def list(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/list',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginQuery.SerializeToString,
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginsInfo.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)

    @staticmethod
    def stat(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/spaceone.api.repository.v1.Plugin/stat',
            spaceone_dot_api_dot_repository_dot_v1_dot_plugin__pb2.PluginStatQuery.SerializeToString,
            google_dot_protobuf_dot_struct__pb2.Struct.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/provisioning/v1/transmission_history.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n7spaceone/api/provisioning/v1/transmission_history.proto\x12\x1cspaceone.api.provisioning.v1\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"Y\n\x18TransmissionHistoryQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x11\n\tdomain_id\x18\x04 \x01(\t\"\xfb\x01\n\x1aTransmissionHistoryRequest\x12\x1f\n\x17transmission_history_id\x18\x01 \x01(\t\x12\x17\n\x0ftransmission_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x14\n\x0cpublish_type\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x0e\n\x06status\x18\x08 \x01(\t\x12\x12\n\ncreated_by\x18\t \x01(\t\x12\x16\n\x0etransaction_id\x18\n \x01(\t\"g\n\x1cTransmissionHistoryStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\xda\x02\n\x17TransmissionHistoryInfo\x12\x1f\n\x17transmission_history_id\x18\x01 \x01(\t\x12\x17\n\x0ftransmission_id\x18\x02 \x01(\t\x12\x11\n\tdomain_id\x18\x03 \x01(\t\x12\x0e\n\x06target\x18\x04 \x01(\t\x12\x14\n\x0cpublish_type\x18\x05 \x01(\t\x12\x12\n\nproject_id\x18\x06 \x01(\t\x12\x1a\n\x12service_account_id\x18\x07 \x01(\t\x12\x16\n\x0eterraform_code\x18\x08 \x01(\t\x12\x0e\n\x06status\x18\t \x01(\t\x12\x0e\n\x06output\x18\n \x01(\t\x12\x12\n\ncreated_by\x18\x0b \x01(\t\x12\x12\n\ncreated_at\x18\x0c \x01(\t\x12\x16\n\x0etransaction_id\x18\r \x01(\t\x12\x12\n\nupdated_at\x18\x0e \x01(\t\x12\x10\n\x08tf_state\x18\x0f \x01(\t\"x\n\x19TransmissionHistoriesInfo\x12\x46\n\x07results\x18\x01 \x03(\x0b\x32\x35.spaceone.api.provisioning.v1.TransmissionHistoryInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\x32\xd8\x06\n\x13TransmissionHistory\x12\xf1\x01\n\x1aget_transmission_histories\x12\x36.spaceone.api.provisioning.v1.TransmissionHistoryQuery\x1a\x37.spaceone.api.provisioning.v1.TransmissionHistoriesInfo\"b\x82\xd3\xe4\x93\x02\\\x12*/provisioning/v1/transmission-history/listZ.\",/provisioning/v1/transmission-history/search\x12\xd4\x01\n\x18get_transmission_history\x12\x38.spaceone.api.provisioning.v1.TransmissionHistoryRequest\x1a\x35.spaceone.api.provisioning.v1.TransmissionHistoryInfo\"G\x82\xd3\xe4\x93\x02\x41\x12?/provisioning/v1/transmission-history/{transmission_history_id}\x12\x90\x01\n\x04stat\x12:.spaceone.api.provisioning.v1.TransmissionHistoryStatQuery\x1a\x17.google.protobuf.Struct\"3\x82\xd3\xe4\x93\x02-\"+/inventory/v1/catalog-resource/history/stat\x12\xe2\x01\n\x1fget_latest_transmission_history\x12\x38.spaceone.api.provisioning.v1.TransmissionHistoryRequest\x1a\x35.spaceone.api.provisioning.v1.TransmissionHistoryInfo\"N\x82\xd3\xe4\x93\x02H\x12\x46/provisioning/v1/transmission-history/latest/{transmission_history_id}b\x06proto3')



_TRANSMISSIONHISTORYQUERY = DESCRIPTOR.message_types_by_name['TransmissionHistoryQuery']
_TRANSMISSIONHISTORYREQUEST = DESCRIPTOR.message_types_by_name['TransmissionHistoryRequest']
_TRANSMISSIONHISTORYSTATQUERY = DESCRIPTOR.message_types_by_name['TransmissionHistoryStatQuery']
_TRANSMISSIONHISTORYINFO = DESCRIPTOR.message_types_by_name['TransmissionHistoryInfo']
_TRANSMISSIONHISTORIESINFO = DESCRIPTOR.message_types_by_name['TransmissionHistoriesInfo']
TransmissionHistoryQuery = _reflection.GeneratedProtocolMessageType('TransmissionHistoryQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryQuery)
  })
_sym_db.RegisterMessage(TransmissionHistoryQuery)

TransmissionHistoryRequest = _reflection.GeneratedProtocolMessageType('TransmissionHistoryRequest', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYREQUEST,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryRequest)
  })
_sym_db.RegisterMessage(TransmissionHistoryRequest)

TransmissionHistoryStatQuery = _reflection.GeneratedProtocolMessageType('TransmissionHistoryStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYSTATQUERY,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryStatQuery)
  })
_sym_db.RegisterMessage(TransmissionHistoryStatQuery)

TransmissionHistoryInfo = _reflection.GeneratedProtocolMessageType('TransmissionHistoryInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORYINFO,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoryInfo)
  })
_sym_db.RegisterMessage(TransmissionHistoryInfo)

TransmissionHistoriesInfo = _reflection.GeneratedProtocolMessageType('TransmissionHistoriesInfo', (_message.Message,), {
  'DESCRIPTOR' : _TRANSMISSIONHISTORIESINFO,
  '__module__' : 'spaceone.api.provisioning.v1.transmission_history_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.provisioning.v1.TransmissionHistoriesInfo)
  })
_sym_db.RegisterMessage(TransmissionHistoriesInfo)

_TRANSMISSIONHISTORY = DESCRIPTOR.services_by_name['TransmissionHistory']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_histories']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_histories']._serialized_options = b'\202\323\344\223\002\\\022*/provisioning/v1/transmission-history/listZ.\",/provisioning/v1/transmission-history/search'
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_history']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_transmission_history']._serialized_options = b'\202\323\344\223\002A\022?/provisioning/v1/transmission-history/{transmission_history_id}'
  _TRANSMISSIONHISTORY.methods_by_name['stat']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002-\"+/inventory/v1/catalog-resource/history/stat'
  _TRANSMISSIONHISTORY.methods_by_name['get_latest_transmission_history']._options = None
  _TRANSMISSIONHISTORY.methods_by_name['get_latest_transmission_history']._serialized_options = b'\202\323\344\223\002H\022F/provisioning/v1/transmission-history/latest/{transmission_history_id}'
  _TRANSMISSIONHISTORYQUERY._serialized_start=183
  _TRANSMISSIONHISTORYQUERY._serialized_end=272
  _TRANSMISSIONHISTORYREQUEST._serialized_start=275
  _TRANSMISSIONHISTORYREQUEST._serialized_end=526
  _TRANSMISSIONHISTORYSTATQUERY._serialized_start=528
  _TRANSMISSIONHISTORYSTATQUERY._serialized_end=631
  _TRANSMISSIONHISTORYINFO._serialized_start=634
  _TRANSMISSIONHISTORYINFO._serialized_end=980
  _TRANSMISSIONHISTORIESINFO._serialized_start=982
  _TRANSMISSIONHISTORIESINFO._serialized_end=1102
  _TRANSMISSIONHISTORY._serialized_start=1105
  _TRANSMISSIONHISTORY._serialized_end=1961
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/inventory/v1/cloud_service_type.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n2spaceone/api/inventory/v1/cloud_service_type.proto\x12\x19spaceone.api.inventory.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"\xb2\x02\n\x1d\x43reateCloudServiceTypeRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x10\n\x08provider\x18\x02 \x01(\t\x12\r\n\x05group\x18\x03 \x01(\t\x12\x14\n\x0cservice_code\x18\x04 \x01(\t\x12\x12\n\nis_primary\x18\x05 \x01(\x08\x12\x10\n\x08is_major\x18\x06 \x01(\x08\x12\x15\n\rresource_type\x18\x07 \x01(\t\x12)\n\x08metadata\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"\xa2\x02\n\x1dUpdateCloudServiceTypeRequest\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x14\n\x0cservice_code\x18\x02 \x01(\t\x12\x12\n\nis_primary\x18\x03 \x01(\x08\x12\x10\n\x08is_major\x18\x04 \x01(\x08\x12\x15\n\rresource_type\x18\x05 \x01(\t\x12)\n\x08metadata\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12%\n\x04tags\x18\r \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x15 \x01(\t\"K\n\x17\x43loudServiceTypeRequest\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\"\\\n\x1aGetCloudServiceTypeRequest\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x0c\n\x04only\x18\x03 \x03(\t\"\x97\x02\n\x15\x43loudServiceTypeQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x1d\n\x15\x63loud_service_type_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x10\n\x08provider\x18\x04 \x01(\t\x12\r\n\x05group\x18\x05 \x01(\t\x12\x1e\n\x16\x63loud_service_type_key\x18\x06 \x01(\t\x12\x14\n\x0cservice_code\x18\x07 \x01(\t\x12\x12\n\nis_primary\x18\x08 \x01(\x08\x12\x10\n\x08is_major\x18\t \x01(\x08\x12\x15\n\rresource_type\x18\n \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"\x90\x03\n\x14\x43loudServiceTypeInfo\x12\x1d\n\x15\x63loud_service_type_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08provider\x18\x03 \x01(\t\x12\r\n\x05group\x18\x04 \x01(\t\x12\x1e\n\x16\x63loud_service_type_key\x18\x05 \x01(\t\x12\x14\n\x0cservice_code\x18\x06 \x01(\t\x12\x12\n\nis_primary\x18\x07 \x01(\x08\x12\x10\n\x08is_major\x18\x08 \x01(\x08\x12\x15\n\rresource_type\x18\t \x01(\t\x12)\n\x08metadata\x18\x0b \x01(\x0b\x32\x17.google.protobuf.Struct\x12%\n\x04tags\x18\x0c \x01(\x0b\x32\x17.google.protobuf.Struct\x12*\n\x06labels\x18\r \x01(\x0b\x32\x1a.google.protobuf.ListValue\x12\x11\n\tdomain_id\x18\x15 \x01(\t\x12\x12\n\ncreated_at\x18\x1f \x01(\t\x12\x12\n\nupdated_at\x18  \x01(\t\"n\n\x15\x43loudServiceTypesInfo\x12@\n\x07results\x18\x01 \x03(\x0b\x32/.spaceone.api.inventory.v1.CloudServiceTypeInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"\x80\x01\n\x19\x43loudServiceTypeStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t\x12\x1a\n\x12\x61llow_delete_state\x18\x03 \x01(\x08\x32\xa4\t\n\x10\x43loudServiceType\x12\x9e\x01\n\x06\x63reate\x12\x38.spaceone.api.inventory.v1.CreateCloudServiceTypeRequest\x1a/.spaceone.api.inventory.v1.CloudServiceTypeInfo\")\x82\xd3\xe4\x93\x02#\"!/inventory/v1/cloud-service-types\x12\xb5\x01\n\x06update\x12\x38.spaceone.api.inventory.v1.UpdateCloudServiceTypeRequest\x1a/.spaceone.api.inventory.v1.CloudServiceTypeInfo\"@\x82\xd3\xe4\x93\x02:\x1a\x38/inventory/v1/cloud-service-type/{cloud_service_type_id}\x12\x96\x01\n\x06\x64\x65lete\x12\x32.spaceone.api.inventory.v1.CloudServiceTypeRequest\x1a\x16.google.protobuf.Empty\"@\x82\xd3\xe4\x93\x02:*8/inventory/v1/cloud-service-type/{cloud_service_type_id}\x12\xaf\x01\n\x03get\x12\x35.spaceone.api.inventory.v1.GetCloudServiceTypeRequest\x1a/.spaceone.api.inventory.v1.CloudServiceTypeInfo\"@\x82\xd3\xe4\x93\x02:\x12\x38/inventory/v1/cloud-service-type/{cloud_service_type_id}\x12\xc1\x01\n\x04list\x12\x30.spaceone.api.inventory.v1.CloudServiceTypeQuery\x1a\x30.spaceone.api.inventory.v1.CloudServiceTypesInfo\"U\x82\xd3\xe4\x93\x02O\x12!/inventory/v1/cloud-service-typesZ*\"(/inventory/v1/cloud-service-types/search\x12\x85\x01\n\x04stat\x12\x34.spaceone.api.inventory.v1.CloudServiceTypeStatQuery\x1a\x17.google.protobuf.Struct\".\x82\xd3\xe4\x93\x02(\"&/inventory/v1/cloud-service-types/stat\x12\x9f\x01\n\x11\x61llow_delete_stat\x12\x34.spaceone.api.inventory.v1.CloudServiceTypeStatQuery\x1a\x17.google.protobuf.Struct\";\x82\xd3\xe4\x93\x02\x35\"3/inventory/v1/cloud-service-types/allow_delete_statb\x06proto3')



_CREATECLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['CreateCloudServiceTypeRequest']
_UPDATECLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['UpdateCloudServiceTypeRequest']
_CLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['CloudServiceTypeRequest']
_GETCLOUDSERVICETYPEREQUEST = DESCRIPTOR.message_types_by_name['GetCloudServiceTypeRequest']
_CLOUDSERVICETYPEQUERY = DESCRIPTOR.message_types_by_name['CloudServiceTypeQuery']
_CLOUDSERVICETYPEINFO = DESCRIPTOR.message_types_by_name['CloudServiceTypeInfo']
_CLOUDSERVICETYPESINFO = DESCRIPTOR.message_types_by_name['CloudServiceTypesInfo']
_CLOUDSERVICETYPESTATQUERY = DESCRIPTOR.message_types_by_name['CloudServiceTypeStatQuery']
CreateCloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('CreateCloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATECLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CreateCloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(CreateCloudServiceTypeRequest)

UpdateCloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('UpdateCloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATECLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.UpdateCloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(UpdateCloudServiceTypeRequest)

CloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('CloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(CloudServiceTypeRequest)

GetCloudServiceTypeRequest = _reflection.GeneratedProtocolMessageType('GetCloudServiceTypeRequest', (_message.Message,), {
  'DESCRIPTOR' : _GETCLOUDSERVICETYPEREQUEST,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.GetCloudServiceTypeRequest)
  })
_sym_db.RegisterMessage(GetCloudServiceTypeRequest)

CloudServiceTypeQuery = _reflection.GeneratedProtocolMessageType('CloudServiceTypeQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPEQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeQuery)
  })
_sym_db.RegisterMessage(CloudServiceTypeQuery)

CloudServiceTypeInfo = _reflection.GeneratedProtocolMessageType('CloudServiceTypeInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPEINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeInfo)
  })
_sym_db.RegisterMessage(CloudServiceTypeInfo)

CloudServiceTypesInfo = _reflection.GeneratedProtocolMessageType('CloudServiceTypesInfo', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPESINFO,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypesInfo)
  })
_sym_db.RegisterMessage(CloudServiceTypesInfo)

CloudServiceTypeStatQuery = _reflection.GeneratedProtocolMessageType('CloudServiceTypeStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _CLOUDSERVICETYPESTATQUERY,
  '__module__' : 'spaceone.api.inventory.v1.cloud_service_type_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.inventory.v1.CloudServiceTypeStatQuery)
  })
_sym_db.RegisterMessage(CloudServiceTypeStatQuery)

_CLOUDSERVICETYPE = DESCRIPTOR.services_by_name['CloudServiceType']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CLOUDSERVICETYPE.methods_by_name['create']._options = None
  _CLOUDSERVICETYPE.methods_by_name['create']._serialized_options = b'\202\323\344\223\002#\"!/inventory/v1/cloud-service-types'
  _CLOUDSERVICETYPE.methods_by_name['update']._options = None
  _CLOUDSERVICETYPE.methods_by_name['update']._serialized_options = b'\202\323\344\223\002:\0328/inventory/v1/cloud-service-type/{cloud_service_type_id}'
  _CLOUDSERVICETYPE.methods_by_name['delete']._options = None
  _CLOUDSERVICETYPE.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002:*8/inventory/v1/cloud-service-type/{cloud_service_type_id}'
  _CLOUDSERVICETYPE.methods_by_name['get']._options = None
  _CLOUDSERVICETYPE.methods_by_name['get']._serialized_options = b'\202\323\344\223\002:\0228/inventory/v1/cloud-service-type/{cloud_service_type_id}'
  _CLOUDSERVICETYPE.methods_by_name['list']._options = None
  _CLOUDSERVICETYPE.methods_by_name['list']._serialized_options = b'\202\323\344\223\002O\022!/inventory/v1/cloud-service-typesZ*\"(/inventory/v1/cloud-service-types/search'
  _CLOUDSERVICETYPE.methods_by_name['stat']._options = None
  _CLOUDSERVICETYPE.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002(\"&/inventory/v1/cloud-service-types/stat'
  _CLOUDSERVICETYPE.methods_by_name['allow_delete_stat']._options = None
  _CLOUDSERVICETYPE.methods_by_name['allow_delete_stat']._serialized_options = b'\202\323\344\223\0025\"3/inventory/v1/cloud-service-types/allow_delete_stat'
  _CREATECLOUDSERVICETYPEREQUEST._serialized_start=205
  _CREATECLOUDSERVICETYPEREQUEST._serialized_end=511
  _UPDATECLOUDSERVICETYPEREQUEST._serialized_start=514
  _UPDATECLOUDSERVICETYPEREQUEST._serialized_end=804
  _CLOUDSERVICETYPEREQUEST._serialized_start=806
  _CLOUDSERVICETYPEREQUEST._serialized_end=881
  _GETCLOUDSERVICETYPEREQUEST._serialized_start=883
  _GETCLOUDSERVICETYPEREQUEST._serialized_end=975
  _CLOUDSERVICETYPEQUERY._serialized_start=978
  _CLOUDSERVICETYPEQUERY._serialized_end=1257
  _CLOUDSERVICETYPEINFO._serialized_start=1260
  _CLOUDSERVICETYPEINFO._serialized_end=1660
  _CLOUDSERVICETYPESINFO._serialized_start=1662
  _CLOUDSERVICETYPESINFO._serialized_end=1772
  _CLOUDSERVICETYPESTATQUERY._serialized_start=1775
  _CLOUDSERVICETYPESTATQUERY._serialized_end=1903
  _CLOUDSERVICETYPE._serialized_start=1906
  _CLOUDSERVICETYPE._serialized_end=3094
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: spaceone/api/notification/v1/quota.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from spaceone.api.core.v1 import query_pb2 as spaceone_dot_api_dot_core_dot_v1_dot_query__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(spaceone/api/notification/v1/quota.proto\x12\x1cspaceone.api.notification.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a spaceone/api/core/v1/query.proto\"d\n\x12\x43reateQuotaRequest\x12\x13\n\x0bprotocol_id\x18\x01 \x01(\t\x12&\n\x05limit\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"a\n\x12UpdateQuotaRequest\x12\x10\n\x08quota_id\x18\x01 \x01(\t\x12&\n\x05limit\x18\x02 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"3\n\x0cQuotaRequest\x12\x10\n\x08quota_id\x18\x01 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"r\n\nQuotaQuery\x12*\n\x05query\x18\x01 \x01(\x0b\x32\x1b.spaceone.api.core.v1.Query\x12\x10\n\x08quota_id\x18\x02 \x01(\t\x12\x13\n\x0bprotocol_id\x18\x03 \x01(\t\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"m\n\tQuotaInfo\x12\x10\n\x08quota_id\x18\x01 \x01(\t\x12\x13\n\x0bprotocol_id\x18\x02 \x01(\t\x12&\n\x05limit\x18\x03 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x11\n\tdomain_id\x18\x0b \x01(\t\"[\n\nQuotasInfo\x12\x38\n\x07results\x18\x01 \x03(\x0b\x32\'.spaceone.api.notification.v1.QuotaInfo\x12\x13\n\x0btotal_count\x18\x02 \x01(\x05\"Y\n\x0eQuotaStatQuery\x12\x34\n\x05query\x18\x01 \x01(\x0b\x32%.spaceone.api.core.v1.StatisticsQuery\x12\x11\n\tdomain_id\x18\x02 \x01(\t2\xb5\x06\n\x05Quota\x12\x84\x01\n\x06\x63reate\x12\x30.spaceone.api.notification.v1.CreateQuotaRequest\x1a\'.spaceone.api.notification.v1.QuotaInfo\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x17/notification/v1/quotas\x12\x8e\x01\n\x06update\x12\x30.spaceone.api.notification.v1.UpdateQuotaRequest\x1a\'.spaceone.api.notification.v1.QuotaInfo\")\x82\xd3\xe4\x93\x02#\x1a!/notification/v1/quota/{quota_id}\x12w\n\x06\x64\x65lete\x12*.spaceone.api.notification.v1.QuotaRequest\x1a\x16.google.protobuf.Empty\")\x82\xd3\xe4\x93\x02#*!/notification/v1/quota/{quota_id}\x12\x85\x01\n\x03get\x12*.spaceone.api.notification.v1.QuotaRequest\x1a\'.spaceone.api.notification.v1.QuotaInfo\")\x82\xd3\xe4\x93\x02#\x12!/notification/v1/quota/{quota_id}\x12\x9d\x01\n\x04list\x12(.spaceone.api.notification.v1.QuotaQuery\x1a(.spaceone.api.notification.v1.QuotasInfo\"A\x82\xd3\xe4\x93\x02;\x12\x17/notification/v1/quotasZ \"\x1e/notification/v1/quotas/search\x12s\n\x04stat\x12,.spaceone.api.notification.v1.QuotaStatQuery\x1a\x17.google.protobuf.Struct\"$\x82\xd3\xe4\x93\x02\x1e\"\x1c/notification/v1/quotas/statb\x06proto3')



_CREATEQUOTAREQUEST = DESCRIPTOR.message_types_by_name['CreateQuotaRequest']
_UPDATEQUOTAREQUEST = DESCRIPTOR.message_types_by_name['UpdateQuotaRequest']
_QUOTAREQUEST = DESCRIPTOR.message_types_by_name['QuotaRequest']
_QUOTAQUERY = DESCRIPTOR.message_types_by_name['QuotaQuery']
_QUOTAINFO = DESCRIPTOR.message_types_by_name['QuotaInfo']
_QUOTASINFO = DESCRIPTOR.message_types_by_name['QuotasInfo']
_QUOTASTATQUERY = DESCRIPTOR.message_types_by_name['QuotaStatQuery']
CreateQuotaRequest = _reflection.GeneratedProtocolMessageType('CreateQuotaRequest', (_message.Message,), {
  'DESCRIPTOR' : _CREATEQUOTAREQUEST,
  '__module__' : 'spaceone.api.notification.v1.quota_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.CreateQuotaRequest)
  })
_sym_db.RegisterMessage(CreateQuotaRequest)

UpdateQuotaRequest = _reflection.GeneratedProtocolMessageType('UpdateQuotaRequest', (_message.Message,), {
  'DESCRIPTOR' : _UPDATEQUOTAREQUEST,
  '__module__' : 'spaceone.api.notification.v1.quota_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.UpdateQuotaRequest)
  })
_sym_db.RegisterMessage(UpdateQuotaRequest)

QuotaRequest = _reflection.GeneratedProtocolMessageType('QuotaRequest', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAREQUEST,
  '__module__' : 'spaceone.api.notification.v1.quota_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.QuotaRequest)
  })
_sym_db.RegisterMessage(QuotaRequest)

QuotaQuery = _reflection.GeneratedProtocolMessageType('QuotaQuery', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAQUERY,
  '__module__' : 'spaceone.api.notification.v1.quota_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.QuotaQuery)
  })
_sym_db.RegisterMessage(QuotaQuery)

QuotaInfo = _reflection.GeneratedProtocolMessageType('QuotaInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUOTAINFO,
  '__module__' : 'spaceone.api.notification.v1.quota_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.QuotaInfo)
  })
_sym_db.RegisterMessage(QuotaInfo)

QuotasInfo = _reflection.GeneratedProtocolMessageType('QuotasInfo', (_message.Message,), {
  'DESCRIPTOR' : _QUOTASINFO,
  '__module__' : 'spaceone.api.notification.v1.quota_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.QuotasInfo)
  })
_sym_db.RegisterMessage(QuotasInfo)

QuotaStatQuery = _reflection.GeneratedProtocolMessageType('QuotaStatQuery', (_message.Message,), {
  'DESCRIPTOR' : _QUOTASTATQUERY,
  '__module__' : 'spaceone.api.notification.v1.quota_pb2'
  # @@protoc_insertion_point(class_scope:spaceone.api.notification.v1.QuotaStatQuery)
  })
_sym_db.RegisterMessage(QuotaStatQuery)

_QUOTA = DESCRIPTOR.services_by_name['Quota']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _QUOTA.methods_by_name['create']._options = None
  _QUOTA.methods_by_name['create']._serialized_options = b'\202\323\344\223\002\031\"\027/notification/v1/quotas'
  _QUOTA.methods_by_name['update']._options = None
  _QUOTA.methods_by_name['update']._serialized_options = b'\202\323\344\223\002#\032!/notification/v1/quota/{quota_id}'
  _QUOTA.methods_by_name['delete']._options = None
  _QUOTA.methods_by_name['delete']._serialized_options = b'\202\323\344\223\002#*!/notification/v1/quota/{quota_id}'
  _QUOTA.methods_by_name['get']._options = None
  _QUOTA.methods_by_name['get']._serialized_options = b'\202\323\344\223\002#\022!/notification/v1/quota/{quota_id}'
  _QUOTA.methods_by_name['list']._options = None
  _QUOTA.methods_by_name['list']._serialized_options = b'\202\323\344\223\002;\022\027/notification/v1/quotasZ \"\036/notification/v1/quotas/search'
  _QUOTA.methods_by_name['stat']._options = None
  _QUOTA.methods_by_name['stat']._serialized_options = b'\202\323\344\223\002\036\"\034/notification/v1/quotas/stat'
  _CREATEQUOTAREQUEST._serialized_start=197
  _CREATEQUOTAREQUEST._serialized_end=297
  _UPDATEQUOTAREQUEST._serialized_start=299
  _UPDATEQUOTAREQUEST._serialized_end=396
  _QUOTAREQUEST._serialized_start=398
  _QUOTAREQUEST._serialized_end=449
  _QUOTAQUERY._serialized_start=451
  _QUOTAQUERY._serialized_end=565
  _QUOTAINFO._serialized_start=567
  _QUOTAINFO._serialized_end=676
  _QUOTASINFO._serialized_start=678
  _QUOTASINFO._serialized_end=769
  _QUOTASTATQUERY._serialized_start=771
  _QUOTASTATQUERY._serialized_end=860
  _QUOTA._serialized_start=863
  _QUOTA._serialized_end=1684
# @@protoc_insertion_point(module_scope)
